summaryrefslogtreecommitdiffstats
path: root/kdf/listview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdf/listview.cpp')
-rw-r--r--kdf/listview.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kdf/listview.cpp b/kdf/listview.cpp
index df11e96..49021ee 100644
--- a/kdf/listview.cpp
+++ b/kdf/listview.cpp
@@ -34,8 +34,8 @@
template class TQDict<TQPixmap>;
-CListView::CListView( TQWidget *tqparent, const char *name, int visibleItem )
- :KListView( tqparent, name ), mVisibleItem(TQMAX( 1, visibleItem ))
+CListView::CListView( TQWidget *parent, const char *name, int visibleItem )
+ :KListView( parent, name ), mVisibleItem(TQMAX( 1, visibleItem ))
{
setVisibleItem(visibleItem);
mPixDict.setAutoDelete(true);
@@ -76,12 +76,12 @@ const TQPixmap &CListView::icon( const TQString &iconName, bool drawBorder )
{
//
// 2000-01-23 Espen Sand
// Careful here: If the tqmask has not been defined we can
// not use TQPixmap::tqmask() because it returns 0 => segfault
//
- if( pix->tqmask() != 0 )
+ if( pix->mask() != 0 )
{
- TQBitmap *bm = new TQBitmap(*(pix->tqmask()));
+ TQBitmap *bm = new TQBitmap(*(pix->mask()));
if( bm != 0 )
{
TQPainter qp(bm);
@@ -76,12 +76,12 @@ const TQPixmap &CListView::icon( const TQString &iconName, bool drawBorder )
//
// 2000-01-23 Espen Sand
- // Careful here: If the tqmask has not been defined we can
- // not use TQPixmap::tqmask() because it returns 0 => segfault
+ // Careful here: If the mask has not been defined we can
+ // not use TQPixmap::mask() because it returns 0 => segfault
//